@@ -13,7 +13,10 @@
 /** enable os buffering in file mapping */
 #define FF_USE_BUFFERING
 
-#if defined __WIN32 || defined _WIN32
+//D.A. #if defined __WIN32 || defined _WIN32
+//B.R. 1.2.20010 #if defined WIN32 || defined WIN64
+//J.O. 16.9.2010: taking from utk_platform_macros.hpp
+#if defined WIN32 || defined _WIN32 || defined __WIN32__ || defined WIN64 || defined _WIN64 || defined __WIN64__
 
 #define FF_USE_WIN32
 
@@ -21,7 +24,9 @@
     as we need GetFileSizeEx instead of GetFileSize to determine
     correct file sizes.
  */
-#define _WIN32_WINNT 0x0500
+
+//B.R. 1.2.20010: moved to Win32FileMapping.hpp
+//#define _WIN32_WINNT 0x0500
 
 #ifndef FF_SECTION_SIZE
 #define FF_SECTION_SIZE (64*1024)
